==> openlit-1.33.9.tar.gz: openlit-1.33.9/src/openlit/instrumentation/assemblyai/__init__.py <==
# pylint: disable=useless-return, bad-staticmethod-argument, disable=duplicate-code
"""Initializer of Auto Instrumentation of AssemblyAI Functions"""

from typing import Collection
import importlib.metadata
from opentelemetry.instrumentation.instrumentor import BaseInstrumentor
from wrapt import wrap_function_wrapper

from openlit.instrumentation.assemblyai.assemblyai import (
    transcribe
)

_instruments = ("assemblyai >= 0.35.1",)

class AssemblyAIInstrumentor(BaseInstrumentor):
    """
    An instrumentor for AssemblyAI's client library.
    """

    def instrumentation_dependencies(self) -> Collection[str]:
        return _instruments

    def _instrument(self, **kwargs):
        application_name = kwargs.get("application_name", "default")
        environment = kwargs.get("environment", "default")
        tracer = kwargs.get("tracer")
        metrics = kwargs.get("metrics_dict")
        pricing_info = kwargs.get("pricing_info", {})
        trace_content = kwargs.get("trace_content", False)
        disable_metrics = kwargs.get("disable_metrics")
        version = importlib.metadata.version("assemblyai")

        # sync transcribe
        wrap_function_wrapper(
            "assemblyai.transcriber",
            "Transcriber.transcribe",
            transcribe(version, environment, application_name,
                  tracer, pricing_info, trace_content, metrics, disable_metrics),
        )

    def _uninstrument(self, **kwargs):
        # Proper uninstrumentation logic to revert patched methods
        pass

==> openlit-1.33.11.tar.gz: openlit-1.33.11/src/openlit/instrumentation/assemblyai/__init__.py <==
# pylint: disable=useless-return, bad-staticmethod-argument, disable=duplicate-code
"""Initializer of Auto Instrumentation of AssemblyAI Functions"""

from typing import Collection
import importlib.metadata
from opentelemetry.instrumentation.instrumentor import BaseInstrumentor
from wrapt import wrap_function_wrapper

from openlit.instrumentation.assemblyai.assemblyai import (
    transcribe
)

_instruments = ("assemblyai >= 0.35.1",)

class AssemblyAIInstrumentor(BaseInstrumentor):
    """
    An instrumentor for AssemblyAI's client library.
    """

    def instrumentation_dependencies(self) -> Collection[str]:
        return _instruments

    def _instrument(self, **kwargs):
        application_name = kwargs.get("application_name", "default")
        environment = kwargs.get("environment", "default")
        tracer = kwargs.get("tracer")
        metrics = kwargs.get("metrics_dict")
        pricing_info = kwargs.get("pricing_info", {})
        capture_message_content = kwargs.get("capture_message_content", False)
        disable_metrics = kwargs.get("disable_metrics")
        version = importlib.metadata.version("assemblyai")

        # sync transcribe
        wrap_function_wrapper(
            "assemblyai.transcriber",
            "Transcriber.transcribe",
            transcribe(version, environment, application_name,
                  tracer, pricing_info, capture_message_content, metrics, disable_metrics),
        )

    def _uninstrument(self, **kwargs):
        # Proper uninstrumentation logic to revert patched methods
        pass
